@@ -109,6 +109,7 @@ def fit(
     train_data: Union[str, TextIO, DocumentArray],
     eval_data: Optional[Union[str, TextIO, DocumentArray]] = None,
     val_split: float = 0.0,
+    model_artifact: Optional[str] = None,
     run_name: Optional[str] = None,
     description: Optional[str] = None,
     experiment_name: Optional[str] = None,
@@ -120,9 +121,10 @@ def fit(
     optimizer_options: Optional[Dict[str, Any]] = None,
     learning_rate: Optional[float] = None,
     epochs: int = 5,
-    batch_size: int = 64,
+    batch_size: Optional[int] = None,
     callbacks: Optional[List[callback.CallbackStubType]] = None,
-    scheduler_step: str = 'batch',
+    scheduler: Optional[str] = None,
+    scheduler_options: Optional[Dict[str, Any]] = None,
     freeze: bool = False,
     output_dim: Optional[int] = None,
     device: str = 'cuda',
@@ -131,6 +133,9 @@ def fit(
     csv_options: Optional[CSVOptions] = None,
     public: bool = False,
     num_items_per_class: int = 4,
+    sampler: str = 'auto',
+    loss_optimizer: Optional[str] = None,
+    loss_optimizer_options: Optional[Dict[str, Any]] = None,
 ) -> Run:
     """Create a Finetuner :class:`Run`, calling this function will submit a fine-tuning
     job to the Jina AI Cloud.
@@ -145,6 +150,9 @@ def fit(
         for calculating a validation loss. If it is set to 0, or an `eval_data`
         parameter is provided, no data is held out from the training data. Instead, the
         `eval_data` is used to calculate the validation loss if it is provided.
+    :param model_artifact: To continue training the training of a model which was
+        fine-tuned by a previous run, you can provide the artifact id of this model,
+        which you can get via :meth:`Run.artifact_id`.
     :param run_name: Name of the run.
     :param description: Run description.
     :param experiment_name: Name of the experiment.
@@ -181,11 +189,16 @@ def fit(
         <https://pytorch.org/docs/stable/optim.html>`_
     :param learning_rate: learning rate for the optimizer.
     :param epochs: Number of epochs for fine-tuning.
-    :param batch_size: Number of items to include in a batch.
+    :param batch_size: Number of items to include in a batch. If not set, the
+        batch size will be configured automatically.
     :param callbacks: List of callback stub objects.
         subpackage for available options, or run `finetuner.list_callbacks()`.
-    :param scheduler_step: At which interval should the learning rate scheduler's
-        step function be called. Valid options are `batch` and `epoch`.
+    :param scheduler: Name of a scheduler to use for learning rate scheduling.
+        Supported types are: `linear`, `cosine`, `cosine_with_restarts`, `polynomial`,
+        `constant`, `constant_with_warmup`.
+    :param scheduler_options: Dictionary of additional parameters to pass to the
+        scheduler: `num_warmup_steps`, `num_training_steps`, and `scheduler_step`
+        (either `batch` or `epoch`).
     :param freeze: If set to `True`, will freeze all layers except the last one.
     :param output_dim: The expected output dimension as `int`.
         If set, will attach a projection head.
@@ -206,6 +219,21 @@ def fit(
         in a batch. For example, if ``batch_size`` is 20, and
         ``num_items_per_class`` is 4, the batch will consist of 4 items for each of
         the 5 classes. Batch size must be divisible by `num_items_per_class`.
+    :param sampler: Determines which sampling method will be used if the
+        data is labeled. Default is `auto`, meaning that the sampler,
+        will be the default for the loss function used.
+        Setting to `class` will result in the `ClassSampler` being used, and setting to
+        `random` will result in the `RandomSampler` being used.
+        If set to `random` then `num_items_per_class` is not used.
+    :param loss_optimizer: Name of the optimizer used for fine-tuning to loss function,
+        if it is a function that requires an optimizer. Options: `Adadelta`, `Adagrad`,
+        `Adam`, `AdamW`, `SparseAdam`, `Adamax`, `ASGD`, `LBFGS`, `NAdam`, `RAdam`,
+        `RMSprop`, `Rprop`, `SGD`. If left as None then optimizer specified by
+        the `optimizer` argument will be used instead.
+    :param loss_optimizer_options: Additional parameters to pass to the optimizer of
+        the loss function. The set of applicable parameters is specific to the optimizer
+        you choose. Details on the parameters can be found in the `PyTorch documentation
+        <https://pytorch.org/docs/stable/optim.html>`_.
 
     .. note::
        Unless necessary, please stick with `device="cuda"`, `cpu` training could be
@@ -217,6 +245,7 @@ def fit(
         train_data=train_data,
         eval_data=eval_data,
         val_split=val_split,
+        model_artifact=model_artifact,
         run_name=run_name,
         description=description,
         experiment_name=experiment_name,
@@ -230,7 +259,8 @@ def fit(
         epochs=epochs,
         batch_size=batch_size,
         callbacks=callbacks,
-        scheduler_step=scheduler_step,
+        scheduler=scheduler,
+        scheduler_options=scheduler_options,
         freeze=freeze,
         output_dim=output_dim,
         device=device,
@@ -239,6 +269,9 @@ def fit(
         csv_options=csv_options,
         public=public,
         num_items_per_class=num_items_per_class,
+        sampler=sampler,
+        loss_optimizer=loss_optimizer,
+        loss_optimizer_options=loss_optimizer_options,
     )
 
 
