@@ -7,7 +7,7 @@ ID = 'id'
 
 HOST = 'JINA_FINETUNER_REGISTRY'
 HUBBLE_REGISTRY = 'JINA_HUBBLE_REGISTRY'
-DEFAULT_FINETUNER_HOST = 'https://api.finetuner.fit'
+DEFAULT_FINETUNER_HOST = 'https://api.compute.finetuner.fit'
 DEFAULT_HUBBLE_REGISTRY = 'https://api.hubble.jina.ai'
 
 CONFIG = 'config'
@@ -20,6 +20,8 @@ RUNS = 'runs'
 STATUS = 'status'
 LOGS = 'logs'
 LOGSTREAM = 'logstream'
+METRICS = 'metrics'
+EXAMPLES = 'examples'
 EXPERIMENTS = 'experiments'
 API_VERSION = 'api/v1'
 AUTHORIZATION = 'Authorization'
@@ -31,11 +33,15 @@ DATA = 'data'
 TRAIN_DATA = 'train_data'
 EVAL_DATA = 'eval_data'
 VAL_SPLIT = 'val_split'
+EVALUATE = 'evaluate'
 ARTIFACTS_DIR = 'artifacts/'
 MODEL = 'model'
 MODEL_OPTIONS = 'model_options'
+MODEL_ARTIFACT = 'model_artifact'
+ARTIFACT = 'artifact'
 ARTIFACT_ID = 'artifact_id'
 DEFAULT_TAG_KEY = 'finetuner_label'
+DEFAULT_TAG_SCORE_KEY = 'finetuner_score'
 # Run status
 CREATED = 'CREATED'
 STARTED = 'STARTED'
@@ -53,6 +59,9 @@ HYPER_PARAMETERS = 'hyper_parameters'
 LOSS = 'loss'
 LOSS_OPTIONS = 'loss_options'
 OPTIMIZER = 'optimizer'
+LOSS_OPTIMIZER = 'loss_optimizer'
+LOSS_OPTIMIZER_OPTIONS = 'loss_optimizer_options'
+SAMPLER = 'sampler'
 MINER = 'miner'
 MINER_OPTIONS = 'miner_options'
 BATCH_SIZE = 'batch_size'
@@ -61,7 +70,8 @@ EPOCHS = 'epochs'
 EXPERIMENT_NAME = 'experiment_name'
 RUN_NAME = 'run_name'
 OPTIMIZER_OPTIONS = 'optimizer_options'
-SCHEDULER_STEP = 'scheduler_step'
+SCHEDULER = 'scheduler'
+SCHEDULER_OPTIONS = 'scheduler_options'
 CALLBACKS = 'callbacks'
 OPTIONS = 'options'
 QUERY_DATA = 'query_data'
