@@ -18,8 +18,11 @@ from finetuner.constants import (
     FREEZE,
     LEARNING_RATE,
     LOSS,
+    LOSS_OPTIMIZER,
+    LOSS_OPTIMIZER_OPTIONS,
     MINER,
     MINER_OPTIONS,
+    MODEL_ARTIFACT,
     MODEL_OPTIONS,
     NAME,
     NUM_ITEMS_PER_CLASS,
@@ -29,10 +32,12 @@ from finetuner.constants import (
     OPTIMIZER_OPTIONS,
     OUTPUT_DIM,
     PUBLIC,
-    SCHEDULER_STEP,
+    SAMPLER,
+    SCHEDULER,
+    SCHEDULER_OPTIONS,
     VAL_SPLIT,
 )
-from finetuner.data import build_finetuning_dataset
+from finetuner.data import CSVContext
 from finetuner.hubble import push_data
 from finetuner.names import get_random_name
 from finetuner.run import Run
@@ -145,20 +150,17 @@ class Experiment:
             if isinstance(callback, EvaluationCallback):
                 eval_callback = callback
 
-        train_data = build_finetuning_dataset(train_data, model, csv_options)
+        csv_context = CSVContext(model=model, options=csv_options)
+        train_data = csv_context.build_dataset(data=train_data)
 
-        eval_data = (
-            build_finetuning_dataset(eval_data, model, csv_options)
-            if eval_data
-            else None
-        )
+        eval_data = csv_context.build_dataset(data=eval_data) if eval_data else None
 
         if eval_callback:
-            eval_callback.query_data = build_finetuning_dataset(
-                eval_callback.query_data, model, csv_options
+            eval_callback.query_data = csv_context.build_dataset(
+                data=eval_callback.query_data,
             )
-            eval_callback.index_data = build_finetuning_dataset(
-                eval_callback.index_data, model, csv_options
+            eval_callback.index_data = csv_context.build_dataset(
+                eval_callback.index_data
             )
 
         train_data, eval_data, query_data, index_data = push_data(
@@ -237,7 +239,8 @@ class Experiment:
         ]
         public = kwargs[PUBLIC] if kwargs.get(PUBLIC) else False
         model = config.ModelConfig(
-            name=model,
+            name=model if not kwargs.get(MODEL_ARTIFACT) else None,
+            artifact=kwargs.get(MODEL_ARTIFACT),
             output_dim=kwargs.get(OUTPUT_DIM),
         )
         if kwargs.get(FREEZE):
@@ -255,6 +258,8 @@ class Experiment:
         )
         if kwargs.get(NUM_WORKERS):
             data.num_workers = kwargs.get(NUM_WORKERS)
+        if kwargs.get(SAMPLER):
+            data.sampler = kwargs.get(SAMPLER)
 
         hyper_parameters = config.HyperParametersConfig(
             miner=kwargs.get(MINER),
@@ -273,8 +278,14 @@ class Experiment:
         if kwargs.get(EPOCHS):
             epochs = kwargs.get(EPOCHS)
             hyper_parameters.epochs = epochs
-        if kwargs.get(SCHEDULER_STEP):
-            hyper_parameters.scheduler_step = kwargs.get(SCHEDULER_STEP)
+        if kwargs.get(SCHEDULER):
+            hyper_parameters.scheduler = kwargs.get(SCHEDULER)
+        if kwargs.get(SCHEDULER_OPTIONS):
+            hyper_parameters.scheduler_options = kwargs.get(SCHEDULER_OPTIONS)
+        if kwargs.get(LOSS_OPTIMIZER):
+            hyper_parameters.loss_optimizer = kwargs.get(LOSS_OPTIMIZER)
+        if kwargs.get(LOSS_OPTIMIZER_OPTIONS):
+            hyper_parameters.loss_optimizer_options = kwargs.get(LOSS_OPTIMIZER_OPTIONS)
 
         run_config = config.RunConfig(
             model=model,
