@@ -146,6 +146,7 @@ class Finetuner:
         train_data: Union[str, DocumentArray],
         eval_data: Optional[Union[str, DocumentArray]] = None,
         val_split: float = 0.0,
+        model_artifact: Optional[str] = None,
         run_name: Optional[str] = None,
         description: Optional[str] = None,
         experiment_name: Optional[str] = None,
@@ -157,9 +158,10 @@ class Finetuner:
         optimizer_options: Optional[Dict[str, Any]] = None,
         learning_rate: Optional[float] = None,
         epochs: int = 5,
-        batch_size: int = 64,
+        batch_size: Optional[int] = None,
         callbacks: Optional[List[Any]] = None,
-        scheduler_step: str = 'batch',
+        scheduler: Optional[str] = None,
+        scheduler_options: Optional[Dict[str, Any]] = None,
         freeze: bool = False,
         output_dim: Optional[int] = None,
         device: str = 'cuda',
@@ -168,6 +170,9 @@ class Finetuner:
         csv_options: Optional[CSVOptions] = None,
         public: bool = False,
         num_items_per_class: int = 4,
+        sampler: str = 'auto',
+        loss_optimizer: Optional[str] = None,
+        loss_optimizer_options: Optional[Dict[str, Any]] = None,
     ) -> Run:
         """Create a run.
 
@@ -185,6 +190,7 @@ class Finetuner:
             train_data=train_data,
             eval_data=eval_data,
             val_split=val_split,
+            model_artifact=model_artifact,
             run_name=run_name,
             description=description,
             model_options=model_options or {},
@@ -197,7 +203,8 @@ class Finetuner:
             epochs=epochs,
             batch_size=batch_size,
             callbacks=callbacks or [],
-            scheduler_step=scheduler_step,
+            scheduler=scheduler,
+            scheduler_options=scheduler_options,
             freeze=freeze,
             output_dim=output_dim,
             device=device,
@@ -206,6 +213,9 @@ class Finetuner:
             csv_options=csv_options,
             public=public,
             num_items_per_class=num_items_per_class,
+            sampler=sampler,
+            loss_optimizer=loss_optimizer,
+            loss_optimizer_options=loss_optimizer_options,
         )
 
     @login_required
